@@ -6,13 +6,15 @@
     workers=0,
     tasks=0L,
     jobname="BPJOB",
-    catch.errors=TRUE,    ## deprecated
     log=FALSE,
+    logdir = NA_character_,
     threshold="INFO",
+    resultdir = NA_character_,
     stop.on.error=TRUE,
     timeout=30L * 24L * 60L * 60L, # 30 days
     exportglobals=TRUE,
-    progressbar=FALSE
+    progressbar=FALSE,
+    RNGseed=NULL
 )
 
 .BiocParallelParam <- setRefClass("BiocParallelParam",
@@ -24,12 +26,16 @@
         progressbar="logical",
         ## required for composeTry
         log="logical",
+        logdir = "character",
         threshold="character",
+        resultdir = "character",
         stop.on.error="logical",
         timeout="integer",
         exportglobals="logical",
-        ## deprecated
-        catch.errors="logical"
+        RNGseed = "ANY",
+        ## cluster management
+        .finalizer_env = "environment",
+        .uid = "character"
     ),
     methods=list(
         show = function() {
@@ -44,9 +50,13 @@
                 "; bpthreshold: ", bpthreshold(.self),
                 "; bpstopOnError: ", bpstopOnError(.self),
                 "\n",
-                "  bptimeout: ", bptimeout(.self),
+                "  bpRNGseed: ", bpRNGseed(.self),
+                "; bptimeout: ", bptimeout(.self),
                 "; bpprogressbar: ", bpprogressbar(.self),
-                "; bpexportglobals: ", bpexportglobals(.self),
+                "\n",
+                "  bpexportglobals: ", bpexportglobals(.self),
+                "\n", .prettyPath("  bplogdir", bplogdir(.self)),
+                "\n", .prettyPath("  bpresultdir", bpresultdir(.self)),
                 "\n", sep="")
         })
 )
@@ -81,13 +91,28 @@ setValidity("BiocParallelParam", function(object)
     if (!.isTRUEorFALSE(bpexportglobals(object)))
         msg <- c(msg, "'bpexportglobals' must be TRUE or FALSE")
 
-    ## error handling
-    if (!.isTRUEorFALSE(bpcatchErrors(object)))
-        msg <- c(msg, "'catch.errors' must be TRUE or FALSE")
-
     if (!.isTRUEorFALSE(bplog(object)))
         msg <- c(msg, "'bplog' must be logical(1)")
 
+    ## log / logdir
+    dir <- bplogdir(object)
+    if (length(dir) != 1L || !is(dir, "character")) {
+        msg <- c(msg, "'logdir' must be character(1)")
+    } else if (!is.na(dir)) {
+        if (!bplog(object))
+            msg <- c(msg, "'log' must be TRUE when 'logdir' is given")
+        if (!.dir_valid_rw(dir))
+            msg <- c(msg, "'logdir' must exist with read / write permission")
+    }
+
+    ## resultdir
+    dir <- bpresultdir(object)
+    if (length(dir) != 1L || !is(dir, "character")) {
+        msg <- c(msg, "'resultdir' must be character(1)")
+    } else if (!is.na(dir) && !.dir_valid_rw(dir)) {
+        msg <- c(msg, "'resultdir' must exist with read / write permissions")
+    }
+
     levels <- c("TRACE", "DEBUG", "INFO", "WARN", "ERROR", "FATAL")
     threshold <- bpthreshold(object)
     if (length(threshold) > 1L) {
@@ -146,12 +171,46 @@ setMethod("bplog", "BiocParallelParam",
     x$log
 })
 
+setMethod("bplogdir", "BiocParallelParam",
+    function(x)
+{
+    x$logdir
+})
+
+setReplaceMethod("bplogdir", c("BiocParallelParam", "character"),
+    function(x, value)
+{
+    if (bpisup(x))
+        stop("use 'bpstop()' before setting 'bplogdir()'")
+
+    x$logdir <- value
+    validObject(x)
+    x
+})
+
 setMethod("bpthreshold", "BiocParallelParam",
     function(x)
 {
     x$threshold
 })
 
+setMethod("bpresultdir", "BiocParallelParam",
+    function(x)
+{
+    x$resultdir
+})
+
+setReplaceMethod("bpresultdir", c("BiocParallelParam", "character"),
+    function(x, value)
+{
+    if (bpisup(x))
+        stop("use 'bpstop()' before setting 'bpresultdir()'")
+
+    x$resultdir <- value
+    validObject(x)
+    x
+})
+
 setMethod("bptimeout", "BiocParallelParam",
     function(x)
 {
@@ -193,19 +252,6 @@ setReplaceMethod("bpstopOnError", c("BiocParallelParam", "logical"),
     x 
 })
 
-setMethod("bpcatchErrors", "BiocParallelParam",
-    function(x)
-{
-    x$catch.errors
-})
-
-setReplaceMethod("bpcatchErrors", c("BiocParallelParam", "logical"),
-    function(x, value)
-{
-    x$catch.errors <- value 
-    x 
-})
-
 setMethod("bpprogressbar", "BiocParallelParam",
     function(x)
 {
@@ -219,6 +265,38 @@ setReplaceMethod("bpprogressbar", c("BiocParallelParam", "logical"),
     x
 })
 
+setMethod("bpRNGseed", "BiocParallelParam",
+    function(x)
+{
+    x$RNGseed
+})
+
+setReplaceMethod("bpRNGseed", c("BiocParallelParam", "NULL"),
+    function(x, value)
+{
+    x$RNGseed <- NULL
+    x
+})
+
+setReplaceMethod("bpRNGseed", c("BiocParallelParam", "numeric"),
+    function(x, value)
+{
+    x$RNGseed <- as.integer(value)
+    x
+})
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Methods - evaluation
+###
+
+setMethod("bpstart", "BiocParallelParam", .bpstart_impl)
+
+setMethod("bpstop", "BiocParallelParam", .bpstop_impl)
+
+setMethod("bplapply", c("ANY", "BiocParallelParam"), .bplapply_impl)
+
+setMethod("bpiterate", c("ANY", "ANY", "BiocParallelParam"), .bpiterate_impl)
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Helpers
 ###
