@@ -65,7 +65,7 @@ setMethod("bplapply", c("ANY", "DoparParam"),
     function(X, FUN, ..., BPREDO=list(), BPPARAM=bpparam())
 {
     if (!length(X))
-        return(list())
+        return(.rename(list(), X))
 
     FUN <- match.fun(FUN)
 
